@@ -143,7 +143,7 @@ def maxcorfreq(s,fs=None, with_xcorr=True):
     s,N,fs = _check_input(s,fs)
     
     if with_xcorr:        
-        s  = operators.correlation(s,mode='full')
+        s  = operators.correlation(s,mode='straight')
         
     s1 = s[1:]
     s2 = s[:-1]
