@@ -9,4 +9,4 @@ from . _marple_sequence import marple_sequence
 
 from .__modulated import modulated_signal
 
-from . import _modulated_utilits is modulations
+from . import _modulated_utilits as modulations
