@@ -41,3 +41,32 @@ def moving_average(vector,av_cof, mode='postw'):
     vector = np.asarray(vector)
     
     return operators.conv_matrix(vector,mode=mode,lags=window.size) @ window/window.size
+
+#---------------------------------------
+def movav(vector,size,straight = True):
+    ''' Alternative Implementation
+    '''
+    vector = np.asarray(vector)
+    N = vector.shape[0]
+    out = np.zeros_like(vector)
+    
+    if straight:
+#         if symmetry:
+        for i in range(N):
+            lp = min(N,i+size//2)
+            fp = max(i-size - size//2,0)
+            out[i] = np.mean(vector[fp:lp])
+#         else:
+#             for i in range(N):
+#                 lp = min(N,i+size)
+#                 out[i] = np.mean(vector[i:lp])
+    else:
+        for i in range(N-1,-1,-1):
+            fp = N-min(N-1,i+size//2)-1
+            lp = N-max(i-size - size//2,0)-1
+            out[N-i-1] = np.mean(vector[fp:lp])
+#         else:
+#             for i in range(N,0,-1):
+#                 lp = N-min(N,i+size)+1
+#                 out[i] = np.mean(vector[N-i+1:lp]) 
+    return out
